#!/bin/bash
#
# sas-ops-agent-update.sh
#
# Note this script will be run in the "sas" user context ONE TIME at
# initial startup of the ops-agent service on a the given host, then it 
# will be renamed to .done.
#
# This script is invoked with arguments for -r rootdir, -d deployid, 
# -i instanceid, and -l logdir, typically: 
#
#    rootdir="/opt/sas/${deployid}"
#    deployid="viya"
#    instanceid="default"
#    logdir="/var/log/sas/${deployid}/${prodname}
#
# Use those values - don't assume any constant paths, since "tenants", etc.
# may use different paths and roots. For example, if your script does 
# complicated things, create a log of its activities off of $logdir
#
# For some special-cases, the $logdir may be NULL. If so, write messages
# to stdout instead.
#
# Other than complaining, the calling script won't do much with non-zero 
# return codes.
#
# Have any commands embedded here do assorted sanity checking of their own, 
# stuff like Viya versions, expected paths and files existing-or-not, etc.
#
# For messages echo'ed to the terminal, indent/lead them by two spaces to help 
# group the output associated with this script.
#

excessargs=""
logdir=""

while [ -n "$1" ]
do
  case "$1" in
    -r)
      shift
      rootdir="$1"
      ;;

    -l)
      shift
      logdir="$1"
      ;;

    -d)
      shift
      deployid="$1"
      ;;

    -i)
      shift
      instance="$1"     # presently unused in template script
      ;;

     *)
# if we don't recognize argument as expected opt, accumulate and let something else consume those
      excessargs="${excessargs} $1"
      ;;
  esac
  shift  # next value
done

date_time=`date +%F_%H-%M-%S`

# Sanity check for required parameters

if [ -z "${rootdir}" ] || [ -z "${deployid}" ] || [ -z "${instance}" ]; then
  echo "  $0: one or more required arguments were not specified."
  exit 1
fi


#
# put your commands here
#

echo "  End of evmcltsvcs update."

exit 0

