#!/bin/bash
#set -x
SCRIPT_NAME="Notification wrapper script"
SCRIPT_VERSION="Viya.20161203"
SCRIPT_BUILD_ID="201612031500"

SCRIPT_PATH=$(dirname $0)

EMI_LOG_FILENAME="$(basename $0 .sh)_scripts.log"

# Include common functions
. "${SCRIPT_PATH}/emi-include.sh"

LogDebug "Log Directory    = ${_LOG_DIR}"
LogDebug "Log Filename     = ${_LOG_FILENAME}"

#Log "== START =="
#LogTerm "Script Location = ${_EMI_COMMON_PATH}"
#LogTerm "Agent Directory = ${_AGENT_DIRECTORY}"
#LogTerm "Plugin Name     = ${_PLUGIN_NAME}"
#LogTerm "Log Directory   = ${_LOG_DIR}"
#LogTerm "Log Filename    = ${_LOG_FILENAME}"
#LogTrace "Test TRACE message 1"
#LogDebug "Test LogDebug message 1"
#LogInfo "Test INFO message 1"
#LogWarn "Test WARN message 1"
#LogError "Test ERROR message 1"
#Log "==  END  =="

# ====================================================================
# FUNCTIONS
# ====================================================================
ShowUsage() {
    LogTerm "Usage: $_SCRIPT_FILENAME [ -h ] [ -v ] [ message ] [ (cmd + args)]"
    exit 2
}

# ====================================================================
# Pulling off options, prepping for execution of requested function 
# ====================================================================
while : 
do
	LogDebug "CLI arg looping $1"
	case "$1" in
		-h | --help)
			ShowUsage
			exit 2
			;;
		-c | --check)
			check="$2"
			shift 2
			inArgs=("$@")
			LogTermDebug "CLI arguments noargs=[${#inArgs[@]}] args=[${inArgs[@]}]"	
			shift ${#inArgs[@]}	
			break
			;;
		-v | --verbose)
			verbose="verbose"
			EMI_LOG_LEVEL="DEBUG"
			shift
			;;
		-*)	
			LogTerm "Error: Unknown option: $1"
			exit 2
			;;
		*)  # No more options
		     args=("$@")
		     shift
		     break
			;;
	esac
done
message=${args[@]:0:1}
check=${args[@]:1}

LogTermDebug "CLI msg=[${message[@]}] cmd=[${check[@]}]"

if [ -z "$check" ]; then
	LogTermError "Missing command"
	ShowUsage
fi 

# Format datetime into ISO8601 variante
# should look as follows: 2016-12-03T15:29:10.555440-05:00  
LogTermDebug "Publish datetime [$_TIME_8601]"

_results=$($check "${inArgs[@]}" 2>&1)
checkrc=$?
LogTermDebug "command [$check] results rc=[$checkrc] Results=[$_results]"

if [ "$checkrc" = "0" ]; then
	exit 0
else if [ "$checkrc" = "3" ]; then
	LogTermError "command [$check failed rc=[$checkrc]. Results=[$_results]" 
	exit 3
	fi
fi

#
# else check returned nonzero return code
# publish results to notification exchange
#
xpubdebug=
if [ "$EMI_LOG_LEVEL" == "DEBUG" ]; then
	xpubdebug="-debug"
fi

rc=
cat <<EOF | xpub -http=false -exchange sas.notification -rc $xpubdebug
{
	"version": 1,
	"timestamp": "$_TIME_8601",
	"name": "broadcast",
	"level": "info",
	"notificationType": "message",
	"notificationVersion": 1,
	"message": "${message}",
	"properties": {
	"_source_": "[$check] rc=[$checkrc]"
    }
}
EOF

rc=$?
if [ "$rc" = "0" ]; then
	LogTermInfo "Notification published"
	exit 0
else
	LogTermError "Failed to publish notification rc=[$rc]"
	exit 2
fi 
